AggregateRating class

Aggregate rating for a product

See: https://schema.org/AggregateRating

Constructors

AggregateRating({required double ratingValue, required int reviewCount, double bestRating = 5.0, double worstRating = 1.0, int? ratingCount})
const

Properties

bestRating → double
final
hashCode → int
The hash code for this object.
no setterinherited
ratingCount → int?
final
ratingValue → double
final
reviewCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
worstRating → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited