ArticleType enum

Article type variants

Inheritance
Available extensions

Values

article → const ArticleType
const ArticleType('Article')
newsArticle → const ArticleType
const ArticleType('NewsArticle')
blogPosting → const ArticleType
const ArticleType('BlogPosting')
techArticle → const ArticleType
const ArticleType('TechArticle')
scholarlyArticle → const ArticleType
const ArticleType('ScholarlyArticle')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ArticleType>
A constant List of the values in this enum, in order of their declaration.