ChangeFrequency enum
How frequently a page is likely to change.
This value provides general information to search engines and may not correlate exactly to how often they crawl the page.
Values
- always → const ChangeFrequency
-
const ChangeFrequency('always') - hourly → const ChangeFrequency
-
const ChangeFrequency('hourly') - daily → const ChangeFrequency
-
const ChangeFrequency('daily') - weekly → const ChangeFrequency
-
const ChangeFrequency('weekly') - monthly → const ChangeFrequency
-
const ChangeFrequency('monthly') - yearly → const ChangeFrequency
-
const ChangeFrequency('yearly') - never → const ChangeFrequency
-
const ChangeFrequency('never')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ChangeFrequency> - A constant List of the values in this enum, in order of their declaration.