EventAttendanceMode enum

Event attendance mode

Inheritance
Available extensions

Values

offline → const EventAttendanceMode
const EventAttendanceMode('https://schema.org/OfflineEventAttendanceMode')
online → const EventAttendanceMode
const EventAttendanceMode('https://schema.org/OnlineEventAttendanceMode')
mixed → const EventAttendanceMode
const EventAttendanceMode('https://schema.org/MixedEventAttendanceMode')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<EventAttendanceMode>
A constant List of the values in this enum, in order of their declaration.