EventOffer class

Event ticket/offer info

Constructors

EventOffer({required String price, String currency = 'USD', String? url, String? validFrom, String? availability})
const

Properties

availability → String?
final
currency → String
final
hashCode → int
The hash code for this object.
no setterinherited
price → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
final
validFrom → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited