EventStatus enum

Event status

Inheritance
Available extensions

Values

scheduled → const EventStatus
const EventStatus('https://schema.org/EventScheduled')
cancelled → const EventStatus
const EventStatus('https://schema.org/EventCancelled')
movedOnline → const EventStatus
const EventStatus('https://schema.org/EventMovedOnline')
postponed → const EventStatus
const EventStatus('https://schema.org/EventPostponed')
rescheduled → const EventStatus
const EventStatus('https://schema.org/EventRescheduled')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<EventStatus>
A constant List of the values in this enum, in order of their declaration.