FaqItem class

A single FAQ question-answer pair.

Constructors

FaqItem({required String question, required String answer})
const

Properties

answer → String
final
hashCode → int
The hash code for this object.
no setterinherited
question → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited