FaqSchema class

Schema.org FAQPage structured data.

Shows expandable FAQ results directly in Google Search.

FaqSchema(questions: [
  FaqItem(
    question: 'What is Flutter?',
    answer: 'Flutter is a UI toolkit by Google...',
  ),
  FaqItem(
    question: 'Is Flutter good for web?',
    answer: 'Yes, Flutter Web supports...',
  ),
])

See: https://schema.org/FAQPage

Inheritance

Constructors

FaqSchema({required List<FaqItem> questions})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
questions List<FaqItem>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() String
Convert to a complete JSON-LD string with @context.
inherited
toJsonLdMinified() String
Convert to a minified JSON-LD string (no extra whitespace).
inherited
toMap() Map<String, dynamic>
Convert this schema to a map (without @context). Subclasses must implement this.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited