ItemCondition enum

Item condition options

Inheritance
Available extensions

Values

newCondition → const ItemCondition
const ItemCondition('https://schema.org/NewCondition')
used → const ItemCondition
const ItemCondition('https://schema.org/UsedCondition')
refurbished → const ItemCondition
const ItemCondition('https://schema.org/RefurbishedCondition')
damaged → const ItemCondition
const ItemCondition('https://schema.org/DamagedCondition')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ItemCondition>
A constant List of the values in this enum, in order of their declaration.