NoscriptFallback class

Manages

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

inject({required String title, String? description, List<NoscriptLink>? links, String? content, List<NoscriptHeading>? headings, List<String>? paragraphs}) → void
Inject noscript fallback content
remove() → void
Remove any injected noscript content