NoscriptLink class

A link entry for noscript fallback content.

Constructors

NoscriptLink({required String href, required String text, String? ariaLabel, String? rel})
const

Properties

ariaLabel → String?
Optional aria-label for accessibility
final
hashCode → int
The hash code for this object.
no setterinherited
href → String
The URL this link points to
final
rel → String?
Optional rel attribute (e.g., 'noopener', 'nofollow')
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
The visible link text
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited