OgType enum

Open Graph content types

Inheritance
Available extensions

Values

website → const OgType
const OgType('website')
article → const OgType
const OgType('article')
product → const OgType
const OgType('product')
profile → const OgType
const OgType('profile')
book → const OgType
const OgType('book')
musicSong → const OgType
const OgType('music.song')
musicAlbum → const OgType
const OgType('music.album')
musicPlaylist → const OgType
const OgType('music.playlist')
videoMovie → const OgType
const OgType('video.movie')
videoEpisode → const OgType
const OgType('video.episode')
videoTvShow → const OgType
const OgType('video.tv_show')
videoOther → const OgType
const OgType('video.other')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OgType>
A constant List of the values in this enum, in order of their declaration.