PersonSchema class

Schema.org Person structured data.

For personal branding, author pages, team member pages, etc.

PersonSchema(
  name: 'John Doe',
  jobTitle: 'Flutter Developer',
  url: 'https://johndoe.dev',
  image: 'https://johndoe.dev/photo.jpg',
  sameAs: [
    'https://twitter.com/johndoe',
    'https://github.com/johndoe',
  ],
)

See: https://schema.org/Person

Inheritance

Constructors

PersonSchema({required String name, String? url, String? image, String? email, String? telephone, String? jobTitle, String? description, String? worksFor, String? alumniOf, String? birthDate, String? nationality, List<String>? sameAs, List<String>? knowsAbout})
const

Properties

alumniOf → String?
final
birthDate → String?
final
description → String?
final
email → String?
final
hashCode → int
The hash code for this object.
no setterinherited
image → String?
final
jobTitle → String?
final
knowsAbout → List<String>?
final
name → String
final
nationality → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sameAs → List<String>?
final
telephone → String?
final
url → String?
final
worksFor → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() → String
Convert to a complete JSON-LD string with @context.
inherited
toJsonLdMinified() → String
Convert to a minified JSON-LD string (no extra whitespace).
inherited
toMap() → Map<String, dynamic>
Convert this schema to a map (without @context). Subclasses must implement this.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited