ProductReview class

Individual product review

See: https://schema.org/Review

Constructors

ProductReview({required String author, required double ratingValue, String? body, String? datePublished, String? reviewTitle})
const

Properties

author → String
final
body → String?
final
datePublished → String?
final
hashCode → int
The hash code for this object.
no setterinherited
ratingValue → double
final
reviewTitle → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited