RendererDetector class

Utility to detect and provide information about the Flutter Web renderer.

This is useful because CanvasKit renders everything to a

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

current RendererType
Get the current renderer type
no setter
isCanvasKit bool
Whether the current renderer is CanvasKit (Skia-based)
no setter
isHtmlRenderer bool
Whether the current renderer is the HTML renderer
no setter
isWeb bool
Whether we're running on web at all
no setter
seoImplications String
Get a human-readable description of SEO implications
no setter