RobotsRule class

A single rule block in robots.txt

Constructors

RobotsRule({String userAgent = '*', List<String> allow = const [], List<String> disallow = const [], int? crawlDelay})
const

Properties

allow → List<String>
final
crawlDelay → int?
final
disallow → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userAgent → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited