SeoAuditResult class

Result of an SEO audit check

Constructors

SeoAuditResult({required AuditSeverity severity, required String rule, required String message, String? fix})
const

Properties

fix String?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
rule String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity AuditSeverity
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited