SeoRouteObserver class

A NavigatorObserver that automatically tracks page views and triggers SEO updates when navigation occurs.

MaterialApp(
  navigatorObservers: [
    SeoRouteObserver(
      onRouteChanged: (routeName) {
        debugPrint('Navigated to: $routeName');
      },
    ),
  ],
)
Inheritance

Constructors

SeoRouteObserver({void onRouteChanged(String routeName)?, bool autoTrackPageViews = true, bool autoUpdateCanonical = false})

Properties

autoTrackPageViews → bool
Whether to automatically track page views on navigation
final
autoUpdateCanonical → bool
Whether to update the canonical URL on navigation
final
hashCode → int
The hash code for this object.
no setterinherited
The navigator that the observer is observing, if any.
no setterinherited
onRouteChanged → void Function(String routeName)?
Callback when the active route changes
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

didChangeTop(Route topRoute, Route? previousTopRoute) → void
The top most route has changed.
inherited
didPop(Route route, Route? previousRoute) → void
The Navigator popped route.
override
didPush(Route route, Route? previousRoute) → void
The Navigator pushed route.
override
didRemove(Route route, Route? previousRoute) → void
The Navigator removed route.
override
didReplace({Route? newRoute, Route? oldRoute}) → void
The Navigator replaced oldRoute with newRoute.
override
didStartUserGesture(Route route, Route? previousRoute) → void
The Navigator's routes are being moved by a user gesture.
inherited
didStopUserGesture() → void
User gesture is no longer controlling the Navigator.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited