SitemapEntry class

A single entry in a sitemap.

SitemapEntry(
  path: '/products/widget',
  priority: 0.8,
  changeFrequency: ChangeFrequency.weekly,
  lastModified: DateTime(2025, 6, 1),
)

Constructors

SitemapEntry({required String path, double priority = 0.5, ChangeFrequency changeFrequency = ChangeFrequency.weekly, DateTime? lastModified})
const

Properties

changeFrequency → ChangeFrequency
How frequently the page is likely to change
final
hashCode → int
The hash code for this object.
no setterinherited
lastModified → DateTime?
The date of last modification
final
path → String
The URL path (e.g., '/products/widget')
final
priority → double
Priority of this URL relative to other URLs on your site. Valid values range from 0.0 to 1.0
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited