SitemapReference class

A reference to a child sitemap in a sitemap index.

Constructors

SitemapReference({required String path, DateTime? lastModified})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastModified → DateTime?
final
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited