TwitterCardType enum

Twitter card type variants

Inheritance
Available extensions

Values

summary → const TwitterCardType

Title, description, and thumbnail image

const TwitterCardType('summary')
summaryLargeImage → const TwitterCardType

Large prominent image with title and description

const TwitterCardType('summary_large_image')
app → const TwitterCardType

App install card (iOS/Android)

const TwitterCardType('app')
player → const TwitterCardType

Video or audio player card

const TwitterCardType('player')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TwitterCardType>
A constant List of the values in this enum, in order of their declaration.