PlausibleProvider class

Stub Plausible provider for non-web platforms.

Inheritance

Constructors

PlausibleProvider({required String domain, String? apiHost, bool hashMode = false})

Properties

apiHost → String?
final
domain → String
final
hashCode → int
The hash code for this object.
no setterinherited
hashMode → bool
final
name → String
Human-readable name of this provider
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Cleanup resources
override
initialize() → void
Initialize the provider (inject scripts, etc.)
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setUserProperties(Map<String, dynamic> properties) → void
Set user properties
inherited
toString() → String
A string representation of this object.
inherited
trackEvent({required String name, Map<String, dynamic>? parameters}) → void
Track a custom event
override
trackPageView({required String path, String? title, Map<String, dynamic>? parameters}) → void
Track a page view
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited