BreadcrumbSchema class
Schema.org BreadcrumbList structured data.
Shows breadcrumb navigation in Google Search results.
BreadcrumbSchema(items: [
BreadcrumbItem(name: 'Home', url: 'https://example.com'),
BreadcrumbItem(name: 'Products', url: 'https://example.com/products'),
BreadcrumbItem(name: 'Widget Pro'), // Last item — no URL needed
])
- Inheritance
-
- Object
- JsonLdSchema
- BreadcrumbSchema
Constructors
-
BreadcrumbSchema({required List<
BreadcrumbItem> items}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
BreadcrumbItem> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → String -
Convert to a complete JSON-LD string with
@context.inherited -
toJsonLdMinified(
) → String -
Convert to a minified JSON-LD string (no extra whitespace).
inherited
-
toMap(
) → Map< String, dynamic> -
Convert this schema to a map (without
@context). Subclasses must implement this.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited