CanonicalUrl class
Manages canonical URL for the current page.
Canonical URLs tell search engines which version of a page is the "official" one, preventing duplicate content issues.
// Set canonical URL
CanonicalUrl.set('https://example.com/products/widget');
// Build canonical from base URL + path
CanonicalUrl.fromPath('/products/widget');
// Remove canonical
CanonicalUrl.remove();
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited