ContactPoint class

Schema.org ContactPoint

See: https://schema.org/ContactPoint

Constructors

ContactPoint({required String telephone, required String contactType, List<String>? areaServed, List<String>? availableLanguage, String? email})
const

Properties

areaServed List<String>?
final
availableLanguage List<String>?
final
contactType String
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
telephone String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited