EventSchema class
Schema.org Event structured data.
For conferences, webinars, meetups, concerts, etc. Shows event rich results in Google Search.
EventSchema(
name: 'FlutterCon 2025',
startDate: '2025-07-15T09:00:00+02:00',
endDate: '2025-07-17T18:00:00+02:00',
location: EventLocation(
name: 'Convention Center',
address: PostalAddress(addressLocality: 'Berlin', addressCountry: 'DE'),
),
description: 'The biggest Flutter conference in Europe',
image: 'https://fluttercon.dev/og.png',
organizer: EventOrganizer(name: 'Flutter Community'),
eventStatus: EventStatus.scheduled,
eventAttendanceMode: EventAttendanceMode.offline,
)
- Inheritance
-
- Object
- JsonLdSchema
- EventSchema
Constructors
-
EventSchema({required String name, required String startDate, String? endDate, String? description, String? image, String? url, EventLocation? location, EventOrganizer? organizer, List<
EventPerformer> ? performers, EventOffer? offer, EventStatus? eventStatus, EventAttendanceMode? eventAttendanceMode, String? previousStartDate}) -
const
Properties
- description → String?
-
final
- endDate → String?
-
final
- eventAttendanceMode → EventAttendanceMode?
-
final
- eventStatus → EventStatus?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- image → String?
-
final
- location → EventLocation?
-
final
- name → String
-
final
- offer → EventOffer?
-
final
- organizer → EventOrganizer?
-
final
-
performers
→ List<
EventPerformer> ? -
final
- previousStartDate → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate → String
-
final
- url → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → String -
Convert to a complete JSON-LD string with
@context.inherited -
toJsonLdMinified(
) → String -
Convert to a minified JSON-LD string (no extra whitespace).
inherited
-
toMap(
) → Map< String, dynamic> -
Convert this schema to a map (without
@context). Subclasses must implement this.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited