HtmlShellPage class

Configuration for a single HTML shell page

Constructors

HtmlShellPage({required String path, required String title, String? description, String? ogImage, String? ogType, String? canonicalUrl, String? jsonLd, String? noscriptContent, Map<String, String>? additionalMeta})
const

Properties

additionalMeta Map<String, String>?
final
canonicalUrl String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
jsonLd String?
final
noscriptContent String?
final
ogImage String?
final
ogType String?
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited