OrganizationSchema class

Schema.org Organization structured data.

Helps Google understand your brand and show knowledge panels.

OrganizationSchema(
  name: 'My Company',
  url: 'https://mycompany.com',
  logo: 'https://mycompany.com/logo.png',
  sameAs: [
    'https://twitter.com/mycompany',
    'https://linkedin.com/company/mycompany',
  ],
)

See: https://schema.org/Organization

Inheritance

Constructors

OrganizationSchema({required String name, String? url, String? description, String? email, String? telephone, List<String>? sameAs, PostalAddress? address, ContactPoint? contactPoint, String? foundingDate, String? numberOfEmployees})
const

Properties

address PostalAddress?
final
contactPoint ContactPoint?
final
description String?
final
email String?
final
foundingDate String?
final
hashCode int
The hash code for this object.
no setterinherited
final
name String
final
numberOfEmployees String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameAs List<String>?
final
telephone String?
final
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() String
Convert to a complete JSON-LD string with @context.
inherited
toJsonLdMinified() String
Convert to a minified JSON-LD string (no extra whitespace).
inherited
toMap() Map<String, dynamic>
Convert this schema to a map (without @context). Subclasses must implement this.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited