PostalAddress class

Schema.org PostalAddress

See: https://schema.org/PostalAddress

Constructors

PostalAddress({String? streetAddress, String? addressLocality, String? addressRegion, String? postalCode, String? addressCountry})
const

Properties

addressCountry String?
final
addressLocality String?
final
addressRegion String?
final
hashCode int
The hash code for this object.
no setterinherited
postalCode String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streetAddress String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited