ProductOffer class
Product offer (price, availability, etc.)
Constructors
- ProductOffer({required String price, String currency = 'USD', ProductAvailability? availability, String? url, String? validUntil, ItemCondition? itemCondition, String? seller})
-
const
Properties
- availability → ProductAvailability?
-
final
- currency → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemCondition → ItemCondition?
-
final
- price → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seller → String?
-
final
- url → String?
-
final
- validUntil → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited