SeoValidator class
Development-time SEO audit tool.
Checks the current page for common SEO issues and prints warnings to the console.
// Run audit on current page
SeoValidator.audit();
// Run audit with specific checks
SeoValidator.auditPage(
title: 'My Page',
description: 'My description',
canonicalUrl: 'https://example.com/page',
);
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited