SocialImageSpec class
Recommended image specifications for a social platform
Constructors
Properties
- aspectRatio → String
-
final
-
formats
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
final
- maxFileSize → String
-
final
- minHeight → int
-
final
- minWidth → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited