UrlUtils class

URL utilities for SEO operations.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

extractPath(String url) String
Extract the path from a full URL
isAbsolute(String url) bool
Check if a URL is absolute (starts with http:// or https://)
join(String baseUrl, String path) String
Join a base URL with a path
makeAbsolute(String url, String baseUrl) String
Make a URL absolute using the base URL
normalize(String url) String
Normalize a URL by removing trailing slashes, fragments, etc.
slugify(String input) String
Create a slug from a string