ValidationIssue class
A validation issue found in a schema
Constructors
- ValidationIssue({required IssueSeverity severity, required String message, String? field})
-
const
Properties
- field → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → IssueSeverity
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited